@@ -131,7 +131,7 @@ struct _EogWrapListPrivate {
 };
 
 static void eog_wrap_list_class_init (EogWrapListClass *class);
-static void eog_wrap_list_instance_init (EogWrapList *wlist);
+static void eog_wrap_list_init (EogWrapList *wlist);
 static void eog_wrap_list_dispose (GObject *object);
 static void eog_wrap_list_finalize (GObject *object);
 
@@ -147,10 +147,7 @@ static void request_update (EogWrapList *wlist);
 static gboolean do_update (EogWrapList *wlist);
 static gint handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpointer data);
 
-GNOME_CLASS_BOILERPLATE (EogWrapList,
-			 eog_wrap_list,
-			 GnomeCanvas,
-			 GNOME_TYPE_CANVAS);
+G_DEFINE_TYPE (EogWrapList, eog_wrap_list, GNOME_TYPE_CANVAS)
 
 /* Class initialization function for the abstract wrapped list view */
 static void
@@ -206,7 +203,7 @@ eog_wrap_list_class_init (EogWrapListClass *class)
 
 /* object initialization function for the abstract wrapped list view */
 static void
-eog_wrap_list_instance_init (EogWrapList *wlist)
+eog_wrap_list_init (EogWrapList *wlist)
 {
 	EogWrapListPrivate *priv;
 
@@ -254,7 +251,7 @@ eog_wrap_list_dispose (GObject *object)
 
 	/* FIXME: free the items and item array */
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+	G_OBJECT_CLASS (eog_wrap_list_parent_class)->dispose (object);
 }
 
 static void
@@ -270,8 +267,8 @@ eog_wrap_list_finalize (GObject *object)
 		g_free (wlist->priv);
 	wlist->priv = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->finalize)
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
+	if (G_OBJECT_CLASS (eog_wrap_list_parent_class)->finalize)
+		(* G_OBJECT_CLASS (eog_wrap_list_parent_class)->finalize) (object);
 }
 
 static void
@@ -325,14 +322,11 @@ get_item_view_position (EogWrapList *wlist, GnomeCanvasItem *item)
 static void
 ensure_item_is_visible (EogWrapList *wlist, GnomeCanvasItem *item)
 {
-	EogWrapListPrivate *priv;
 	double x1, y1, x2, y2;
 	int width, height;
 	int ofsx, ofsy;
 	int scroll_x, scroll_y;
 
-	priv = wlist->priv;
-
 	width = GTK_WIDGET (wlist)->allocation.width;
 	height = GTK_WIDGET (wlist)->allocation.height;
 	gnome_canvas_get_scroll_offsets (GNOME_CANVAS (wlist), &ofsx, &ofsy);
@@ -593,83 +587,21 @@ eog_wrap_list_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	wlist = EOG_WRAP_LIST (widget);
 	priv = wlist->priv;
 
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
+	GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->size_allocate (widget,
+								    allocation);
 
 	priv->global_update_hints[GLOBAL_WIDGET_SIZE_CHANGED] = TRUE;
 
 	request_update (wlist);
 }       
 
-static void 
-eog_wrap_list_select_up (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-	int i;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-
-	for (i = 0; i < priv->n_cols && node != NULL; i++) {
-		node = node->prev;
-	}
-	if (node == NULL) return;
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-static void 
-eog_wrap_list_select_down (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-	int i;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-
-	for (i = 0; i < priv->n_cols && node != NULL; i++) {
-		node = node->next;
-	}
-	if (node == NULL) return;
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
 void 
-eog_wrap_list_select_left (EogWrapList *wlist)
+eog_wrap_list_select_single (EogWrapList *wlist, EogWrapListSelectChange change)
 {
 	EogWrapListPrivate *priv;
 	GList *node;
 	GnomeCanvasItem *item;
+	int i;
 
 	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
 
@@ -678,93 +610,42 @@ eog_wrap_list_select_left (EogWrapList *wlist)
 	if (priv->n_selected_items != 1) return;
 
 	node = g_list_find (priv->view_order, priv->last_item_clicked);
+
 	if (node == NULL) return;
 
-	node = node->prev;
-	if (node == NULL) {
-		node = g_list_last (priv->view_order);
-	}
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-void
-eog_wrap_list_select_right (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-	if (node == NULL) return;
-
-	node = node->next;
-	if (node == NULL) {
+	switch (change) {
+	case EOG_WRAP_LIST_SELECT_UP:
+		for (i = 0; i < priv->n_cols && node != NULL; i++) {
+			node = node->prev;
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_DOWN:
+		for (i = 0; i < priv->n_cols && node != NULL; i++) {
+			node = node->next;
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_LEFT:
+		node = node->prev;
+		if (node == NULL) {
+			node = g_list_last (priv->view_order);
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_RIGHT:
+		node = node->next;
+		if (node == NULL) {
+			node = g_list_first (priv->view_order);
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_FIRST:
 		node = g_list_first (priv->view_order);
+		break;
+	case EOG_WRAP_LIST_SELECT_LAST:
+		node = g_list_last (priv->view_order);
+		break;
+	default:
+		g_assert_not_reached ();
 	}
 
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-void
-eog_wrap_list_select_first (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	node = g_list_first (priv->view_order);
-	if (node == NULL) return;
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-void
-eog_wrap_list_select_last (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	node = g_list_last (priv->view_order);
 	if (node == NULL) return;
 
 	item = GNOME_CANVAS_ITEM (node->data);
@@ -785,28 +666,33 @@ eog_wrap_list_key_press_cb (GtkWidget *widget, GdkEventKey *event)
 
 	switch (event->keyval) {
 	case GDK_Up:
-		eog_wrap_list_select_up (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_UP);
 		handled = TRUE;
 		break;
 
 	case GDK_Down:
-		eog_wrap_list_select_down (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_DOWN);
 		handled = TRUE;
 		break;
 
 	case GDK_Left:
-		eog_wrap_list_select_left (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_LEFT);
 		handled = TRUE;
 		break;
 
 	case GDK_Right:
-		eog_wrap_list_select_right (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_RIGHT);
 		handled = TRUE;
 		break;
 	};
 
 	if (!handled) 
-		handled = GNOME_CALL_PARENT_WITH_DEFAULT (GTK_WIDGET_CLASS, key_press_event, (widget, event), FALSE);
+	{
+		if (GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->key_press_event)
+			handled = GTK_WIDGET_CLASS (eog_wrap_list_parent_class)->key_press_event (widget, event);
+		else
+			handled = FALSE;
+	}
 
 	return handled;
 }
@@ -967,7 +853,6 @@ model_image_removed (EogImageList *model, int pos, gpointer data)
 	EogWrapListPrivate *priv;
 	GnomeCanvasItem *item;
 	GList *node;
-	gboolean selection_changed;
 
 	g_return_if_fail (EOG_IS_WRAP_LIST (data));
 
@@ -984,7 +869,7 @@ model_image_removed (EogImageList *model, int pos, gpointer data)
 		priv->last_item_clicked = NULL;
 	}
 	
-	selection_changed = set_select_status (wlist, EOG_COLLECTION_ITEM (item), FALSE);
+	set_select_status (wlist, EOG_COLLECTION_ITEM (item), FALSE);
 	priv->view_order = g_list_delete_link (priv->view_order, node);
 
 	/* delete object */
@@ -1119,7 +1004,6 @@ do_layout_check (EogWrapList *wlist)
 	unsigned int n_rows_new = 0;
 	unsigned int n_cols_new = 0;
 	gint cw;
-	gint ch;
 	
 	EogWrapListPrivate *priv;
 
@@ -1134,7 +1018,6 @@ do_layout_check (EogWrapList *wlist)
 
 	/* get canvas width */
 	cw = GTK_WIDGET (wlist)->allocation.width;
-	ch = GTK_WIDGET (wlist)->allocation.height;
 
 	/* calculate new number of  columns/rows */
 	n_cols_new = cw / (EOG_COLLECTION_ITEM_MAX_WIDTH + priv->col_spacing);
