@@ -2,6 +2,7 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <glib/gi18n.h>
+#include <libgnome/gnome-help.h>
 #include "util.h"
 #include "eog-preferences.h"
 #include "eog-config-keys.h"
@@ -31,28 +32,6 @@ check_toggle_cb (GtkWidget *widget, gpointer data)
 			       NULL);
 }
 
-static void
-check_auto_advance_toggle_cb (GtkWidget *widget, gpointer data)
-{
-	char *key = NULL;
-	GtkWidget *child = NULL;
-	gboolean state = FALSE;
-
-	key = g_object_get_data (G_OBJECT (widget), GCONF_OBJECT_KEY);
-	if (key == NULL) return;
-
-	state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	
-	gconf_client_set_bool (GCONF_CLIENT (data),
-			       key, state,			       
-			       NULL);
-	
-	child = g_object_get_data (G_OBJECT (widget), OBJECT_WIDGET);
-	if (child != NULL) {
-		g_object_set (child, "sensitive", state, NULL);
-	}
-}
-
 static void
 spin_button_changed_cb (GtkWidget *widget, gpointer data)
 {
@@ -241,16 +220,6 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 			  G_CALLBACK (check_toggle_cb), 
 			  client);
 
-	widget = glade_xml_get_widget (xml, "auto_advance_check");	
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), 
-				      gconf_client_get_bool (client, EOG_CONF_FULLSCREEN_AUTO_ADVANCE, NULL));
-	g_object_set_data (G_OBJECT (widget), OBJECT_WIDGET, glade_xml_get_widget (xml, "seconds_hbox"));
-	g_object_set_data (G_OBJECT (widget), GCONF_OBJECT_KEY, EOG_CONF_FULLSCREEN_AUTO_ADVANCE);
-	g_signal_connect (G_OBJECT (widget), 
-			  "toggled", 
-			  G_CALLBACK (check_auto_advance_toggle_cb), 
-			  client);
-
 	widget = glade_xml_get_widget (xml, "seconds_spin");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), 
 				   gconf_client_get_int (client, EOG_CONF_FULLSCREEN_SECONDS, NULL));
@@ -260,11 +229,6 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 			  G_CALLBACK (spin_button_changed_cb), 
 			  client);
 			  
-	if (!gconf_client_get_bool (client, EOG_CONF_FULLSCREEN_AUTO_ADVANCE, NULL)) {
-		widget = glade_xml_get_widget (xml, "seconds_hbox");
-		g_object_set (widget, "sensitive", FALSE, NULL);
-	}
-
 	gtk_window_set_transient_for (GTK_WINDOW (dlg), parent);
 	gtk_widget_show_all (dlg);
 }
